(pingus-controller
 (standard-pointer
  (xinput:pointer (device "gstylus")))

 (primary-button
  )

 (secondary-button
  )

 (pause-button
  )

 (fast-forward-button
  )

 (armageddon-button
  )

 (escape-button
  (sdl:keyboard-button (key "escape")))

 (action-axis
  )

 (action-up-button
  )

 (action-down-button
  )
 )

;; EOF ;;
